@@ -962,10 +962,10 @@ def release_branch(module_list, tag_path, c_path, f_branch):
 
 
 def printTable(list, info):
-    error_table = PrettyTable("编号", "组件名", "分支", "错误信息")
+    error_table = PrettyTable(["编号", "组件名", "分支", "错误信息"])
     for index in range(0, len(list) - 1):
         model = list[index]
-        error_table.add_row(index, model.module, model.branch, model.msg)
+        error_table.add_row([index, model.module, model.branch, model.msg])
     error_table.align[1] = '1'
     error_table.border = True
     error_table.junction_char = '+'
